"""Version information for rxiv-maker."""

__version__ = "1.4.21"
__version_tuple__ = (1, 4, 21)

# Note: Docker images v1.8+ use mermaid.ink API for diagram processing
# This improves cross-platform compatibility and performance
